From 705d4182c8a84728e7f00cf48110c8f9720e4c29 Mon Sep 17 00:00:00 2001
From: Merov Linden <merov@lindenlab.com>
Date: Thu, 13 Mar 2014 16:45:52 -0700
Subject: [PATCH] DD-42 : Rename merchant items to marketplace listings to be
 consistent with spec

---
 indra/llcommon/llfoldertype.cpp               |   2 +-
 indra/llcommon/llfoldertype.h                 |   2 +-
 indra/newview/llfloateroutbox.cpp             | 114 +++++++++---------
 indra/newview/llfloateroutbox.h               |  12 +-
 indra/newview/llinventorybridge.cpp           |   6 +-
 indra/newview/llinventorybridge.h             |   2 +-
 indra/newview/llinventorypanel.cpp            |   4 +-
 indra/newview/llviewerfloaterreg.cpp          |   2 +-
 indra/newview/llviewerfoldertype.cpp          |   2 +-
 ...s.xml => floater_marketplace_listings.xml} |  14 +--
 .../skins/default/xui/en/menu_viewer.xml      |   6 +-
 ... panel_marketplace_listings_inventory.xml} |   4 +-
 .../newview/skins/default/xui/en/strings.xml  |   6 +-
 13 files changed, 88 insertions(+), 88 deletions(-)
 rename indra/newview/skins/default/xui/en/{floater_merchant_items.xml => floater_marketplace_listings.xml} (88%)
 rename indra/newview/skins/default/xui/en/{panel_merchant_items_inventory.xml => panel_marketplace_listings_inventory.xml} (91%)

diff --git a/indra/llcommon/llfoldertype.cpp b/indra/llcommon/llfoldertype.cpp
index 64bc17c4220..5b80189d2ad 100755
--- a/indra/llcommon/llfoldertype.cpp
+++ b/indra/llcommon/llfoldertype.cpp
@@ -97,7 +97,7 @@ LLFolderDictionary::LLFolderDictionary()
 	
 	addEntry(LLFolderType::FT_BASIC_ROOT,			new FolderEntry("basic_rt", TRUE));
 
-	addEntry(LLFolderType::FT_MERCHANT_ITEMS, 		new FolderEntry("merchant", FALSE));
+	addEntry(LLFolderType::FT_MARKETPLACE_LISTINGS, new FolderEntry("merchant", FALSE));
 		 
 	addEntry(LLFolderType::FT_NONE, 				new FolderEntry("-1",		FALSE));
 };
diff --git a/indra/llcommon/llfoldertype.h b/indra/llcommon/llfoldertype.h
index 81f9c0b678f..91dc1da5433 100644
--- a/indra/llcommon/llfoldertype.h
+++ b/indra/llcommon/llfoldertype.h
@@ -87,7 +87,7 @@ class LL_COMMON_API LLFolderType
 
 		FT_BASIC_ROOT = 52,
 
-		FT_MERCHANT_ITEMS = 53,
+		FT_MARKETPLACE_LISTINGS = 53,
 
 		FT_COUNT,
 
diff --git a/indra/newview/llinventorybridge.cpp b/indra/newview/llinventorybridge.cpp
index c2f6ce8fb13..9d9279ce90f 100755
--- a/indra/newview/llinventorybridge.cpp
+++ b/indra/newview/llinventorybridge.cpp
@@ -959,9 +959,9 @@ BOOL LLInvFVBridge::isInboxFolder() const
 	return gInventory.isObjectDescendentOf(mUUID, inbox_id);
 }
 
-BOOL LLInvFVBridge::isMerchantItemsFolder() const
+BOOL LLInvFVBridge::isMarketplaceListingsFolder() const
 {
-	const LLUUID folder_id = gInventory.findCategoryUUIDForType(LLFolderType::FT_MERCHANT_ITEMS, false);
+	const LLUUID folder_id = gInventory.findCategoryUUIDForType(LLFolderType::FT_MARKETPLACE_LISTINGS, false);
 	
 	if (folder_id.isNull())
 	{
@@ -1954,7 +1954,7 @@ std::string LLFolderBridge::getLabelSuffix() const
      accessories = (parent_folder_id == gInventory.getLibraryRootFolderID());
      }
      */
-    if (isMerchantItemsFolder())
+    if (isMarketplaceListingsFolder())
     {
         if (LLMarketplaceData::instance().isListed(getUUID()))
         {
diff --git a/indra/newview/llinventorypanel.cpp b/indra/newview/llinventorypanel.cpp
index c1607fbbc00..bf8f7819efb 100755
--- a/indra/newview/llinventorypanel.cpp
+++ b/indra/newview/llinventorypanel.cpp
@@ -288,7 +288,7 @@ void LLInventoryPanel::initFromParams(const LLInventoryPanel::Params& params)
 	{
 		getFilter().setFilterCategoryTypes(getFilter().getFilterCategoryTypes() & ~(1ULL << LLFolderType::FT_INBOX));
 		getFilter().setFilterCategoryTypes(getFilter().getFilterCategoryTypes() & ~(1ULL << LLFolderType::FT_OUTBOX));
-		getFilter().setFilterCategoryTypes(getFilter().getFilterCategoryTypes() & ~(1ULL << LLFolderType::FT_MERCHANT_ITEMS));
+		getFilter().setFilterCategoryTypes(getFilter().getFilterCategoryTypes() & ~(1ULL << LLFolderType::FT_MARKETPLACE_LISTINGS));
 	}
 
 	// set the filter for the empty folder if the debug setting is on
@@ -1490,6 +1490,6 @@ namespace LLInitParam
 		declare(LLFolderType::lookup(LLFolderType::FT_INBOX)            , LLFolderType::FT_INBOX);
 		declare(LLFolderType::lookup(LLFolderType::FT_OUTBOX)           , LLFolderType::FT_OUTBOX);
 		declare(LLFolderType::lookup(LLFolderType::FT_BASIC_ROOT)       , LLFolderType::FT_BASIC_ROOT);
-		declare(LLFolderType::lookup(LLFolderType::FT_MERCHANT_ITEMS)   , LLFolderType::FT_MERCHANT_ITEMS);
+		declare(LLFolderType::lookup(LLFolderType::FT_MARKETPLACE_LISTINGS)   , LLFolderType::FT_MARKETPLACE_LISTINGS);
 	}
 }
diff --git a/indra/newview/llviewerfloaterreg.cpp b/indra/newview/llviewerfloaterreg.cpp
index f55de790d84..853d98693b9 100755
--- a/indra/newview/llviewerfloaterreg.cpp
+++ b/indra/newview/llviewerfloaterreg.cpp
@@ -243,7 +243,7 @@ void LLViewerFloaterReg::registerFloaters()
 		LLFloaterReg::add("tex_fetch_debugger", "floater_texture_fetch_debugger.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterTextureFetchDebugger>);
 	}
 	LLFloaterReg::add("media_settings", "floater_media_settings.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterMediaSettings>);	
-	LLFloaterReg::add("merchant_items", "floater_merchant_items.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterMerchantItems>);
+	LLFloaterReg::add("marketplace_listings", "floater_marketplace_listings.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterMarketplaceListings>);
 	LLFloaterReg::add("message_critical", "floater_critical.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterTOS>);
 	LLFloaterReg::add("message_tos", "floater_tos.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterTOS>);
 	LLFloaterReg::add("moveview", "floater_moveview.xml", (LLFloaterBuildFunc)&LLFloaterReg::build<LLFloaterMove>);
diff --git a/indra/newview/llviewerfoldertype.cpp b/indra/newview/llviewerfoldertype.cpp
index 413814cec0b..ee8f85782fc 100644
--- a/indra/newview/llviewerfoldertype.cpp
+++ b/indra/newview/llviewerfoldertype.cpp
@@ -141,7 +141,7 @@ LLViewerFolderDictionary::LLViewerFolderDictionary()
 
 	addEntry(LLFolderType::FT_BASIC_ROOT, 			new ViewerFolderEntry("Basic Root",				"Inv_SysOpen",			"Inv_SysClosed",		FALSE,     true));
 
-	addEntry(LLFolderType::FT_MERCHANT_ITEMS, 		new ViewerFolderEntry("Merchant items",         "Inv_SysOpen",			"Inv_SysClosed",		FALSE,     boxes_invisible));
+	addEntry(LLFolderType::FT_MARKETPLACE_LISTINGS, new ViewerFolderEntry("Marketplace listings",   "Inv_SysOpen",			"Inv_SysClosed",		FALSE,     boxes_invisible));
 		 
 	addEntry(LLFolderType::FT_NONE, 				new ViewerFolderEntry("New Folder",				"Inv_FolderOpen",		"Inv_FolderClosed",		FALSE,     false, "default"));
 
diff --git a/indra/newview/skins/default/xui/en/floater_merchant_items.xml b/indra/newview/skins/default/xui/en/floater_marketplace_listings.xml
similarity index 88%
rename from indra/newview/skins/default/xui/en/floater_merchant_items.xml
rename to indra/newview/skins/default/xui/en/floater_marketplace_listings.xml
index 2e54ed2ce31..94a9466c16d 100755
--- a/indra/newview/skins/default/xui/en/floater_merchant_items.xml
+++ b/indra/newview/skins/default/xui/en/floater_marketplace_listings.xml
@@ -4,14 +4,14 @@
     can_close="true"
     can_resize="true"
     height="440"
-    help_topic="floater_merchant_items"
+    help_topic="floater_marketplace_listings"
     min_width="300"
     min_height="200"
-    name="floater_merchant_items"
+    name="floater_marketplace_listings"
     save_rect="true"
     save_visibility="false"
     reuse_instance="true"
-    title="MERCHANT ITEMS"
+    title="MARKETPLACE LISTINGS"
     width="333">
   <panel
       follows="all"
@@ -29,7 +29,7 @@
         top="0"
         bg_opaque_color="InventoryBackgroundColor">
         <panel
-            name="merchant_items_inventory_placeholder_panel"
+            name="marketplace_listings_inventory_placeholder_panel"
             follows="all"
             layout="topleft"
             top="0"
@@ -38,7 +38,7 @@
             height="370"
             bg_opaque_color="InventoryBackgroundColor">
             <text
-                name="merchant_items_inventory_placeholder_title"
+                name="marketplace_listings_inventory_placeholder_title"
                 type="string"
                 follows="top|left|right"
                 layout="topleft"
@@ -52,7 +52,7 @@
                 Loading...
             </text>
             <text
-            name="merchant_items_inventory_placeholder_text"
+            name="marketplace_listings_inventory_placeholder_text"
             type="string"
             follows="top|left|right"
             layout="topleft"
@@ -71,7 +71,7 @@
         width="313"
         top="370">
       <panel
-          name="merchant_items_generic_drag_target"
+          name="marketplace_listings_generic_drag_target"
           mouse_opaque="false"
           follows="all"
           top="5"
diff --git a/indra/newview/skins/default/xui/en/menu_viewer.xml b/indra/newview/skins/default/xui/en/menu_viewer.xml
index 2dc974eff1b..a8e02a9d028 100755
--- a/indra/newview/skins/default/xui/en/menu_viewer.xml
+++ b/indra/newview/skins/default/xui/en/menu_viewer.xml
@@ -182,11 +182,11 @@
          parameter="outbox" />
       </menu_item_call>
         <menu_item_call
-            label="Merchant Items..."
-            name="MerchantItems">
+            label="Marketplace listings..."
+            name="MarketplaceListings">
             <menu_item_call.on_click
             function="Floater.ToggleOrBringToFront"
-            parameter="merchant_items" />
+            parameter="marketplace_listings" />
         </menu_item_call>
       <menu_item_call
            label="Account dashboard..."
diff --git a/indra/newview/skins/default/xui/en/panel_merchant_items_inventory.xml b/indra/newview/skins/default/xui/en/panel_marketplace_listings_inventory.xml
similarity index 91%
rename from indra/newview/skins/default/xui/en/panel_merchant_items_inventory.xml
rename to indra/newview/skins/default/xui/en/panel_marketplace_listings_inventory.xml
index a0135162674..dcb634fe597 100755
--- a/indra/newview/skins/default/xui/en/panel_merchant_items_inventory.xml
+++ b/indra/newview/skins/default/xui/en/panel_marketplace_listings_inventory.xml
@@ -1,7 +1,7 @@
 <?xml version="1.0" encoding="utf-8" standalone="yes" ?>
 <inventory_panel
-    name="inventory_merchant_items"
-    start_folder.name="Merchant items"
+    name="inventory_marketplace_listings"
+    start_folder.name="Marketplace listings"
     show_empty_message="false"
     show_load_status="false"
     start_folder.type="merchant"
diff --git a/indra/newview/skins/default/xui/en/strings.xml b/indra/newview/skins/default/xui/en/strings.xml
index 515e912ee53..387ad138d9c 100755
--- a/indra/newview/skins/default/xui/en/strings.xml
+++ b/indra/newview/skins/default/xui/en/strings.xml
@@ -2219,9 +2219,9 @@ We are accessing your account on the [[MARKETPLACE_CREATE_STORE_URL] Marketplace
 	<string name="InventoryOutboxError">
 The [[MARKETPLACE_CREATE_STORE_URL] Marketplace store] is returning errors.
 	</string>
-	<string name="InventoryMerchantItemsNoItemsTitle">Your Merchant Items folder is empty.</string>
-	<string name="InventoryMerchantItemsNoItemsTooltip"></string>
-	<string name="InventoryMerchantItemsNoItems">
+	<string name="InventoryMarketplaceListingsNoItemsTitle">Your Marketplace Listings folder is empty.</string>
+	<string name="InventoryMarketplaceListingsNoItemsTooltip"></string>
+	<string name="InventoryMarketplaceListingsNoItems">
         Drag folders to this area to list them for sale on the [[MARKETPLACE_DASHBOARD_URL] Marketplace].
 	</string>
 
diff --git a/indra/newview/llfloateroutbox.cpp b/indra/newview/llfloateroutbox.cpp
index 8f4daa83f9b..2ed4605e0c6 100755
--- a/indra/newview/llfloateroutbox.cpp
+++ b/indra/newview/llfloateroutbox.cpp
@@ -1,8 +1,8 @@
 /** 
  * @file llfloateroutbox.cpp
  * @brief Implementation of the merchant outbox window and of the merchant items window
  *
  * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermerchantitems
  *
  * $LicenseInfo:firstyear=2001&license=viewerlgpl$
  * Second Life Viewer Source Code
@@ -107,15 +107,15 @@ class LLOutboxAddedObserver : public LLInventoryCategoryAddedObserver
 };
 
 ///----------------------------------------------------------------------------
 /// LLMerchantItemsAddedObserver helper class
 ///----------------------------------------------------------------------------
 
-class LLMerchantItemsAddedObserver : public LLInventoryCategoryAddedObserver
+class LLMarketplaceListingsAddedObserver : public LLInventoryCategoryAddedObserver
 {
 public:
-	LLMerchantItemsAddedObserver(LLFloaterMerchantItems * merchant_items_floater)
+	LLMarketplaceListingsAddedObserver(LLFloaterMarketplaceListings * marketplace_listings_floater)
     : LLInventoryCategoryAddedObserver()
-    , mMerchantItemsFloater(merchant_items_floater)
+    , mMarketplaceListingsFloater(marketplace_listings_floater)
 	{
 	}
 	
@@ -127,15 +127,15 @@ class LLMerchantItemsAddedObserver : public LLInventoryCategoryAddedObserver
 			
 			LLFolderType::EType added_category_type = added_category->getPreferredType();
 			
-			if (added_category_type == LLFolderType::FT_MERCHANT_ITEMS)
+			if (added_category_type == LLFolderType::FT_MARKETPLACE_LISTINGS)
 			{
-				mMerchantItemsFloater->initializeMarketPlace();
+				mMarketplaceListingsFloater->initializeMarketPlace();
 			}
 		}
 	}
 	
 private:
-	LLFloaterMerchantItems *	mMerchantItemsFloater;
+	LLFloaterMarketplaceListings *	mMarketplaceListingsFloater;
 };
 
 
@@ -653,10 +653,10 @@ void LLFloaterOutbox::showNotification(const LLNotificationPtr& notification)
 }
 
 ///----------------------------------------------------------------------------
-/// LLFloaterMerchantItems
+/// LLFloaterMarketplaceListings
 ///----------------------------------------------------------------------------
 
-LLFloaterMerchantItems::LLFloaterMerchantItems(const LLSD& key)
+LLFloaterMarketplaceListings::LLFloaterMarketplaceListings(const LLSD& key)
 : LLFloater(key)
 , mCategoriesObserver(NULL)
 , mCategoryAddedObserver(NULL)
@@ -668,7 +668,7 @@ LLFloaterMerchantItems::LLFloaterMerchantItems(const LLSD& key)
 {
 }
 
-LLFloaterMerchantItems::~LLFloaterMerchantItems()
+LLFloaterMarketplaceListings::~LLFloaterMarketplaceListings()
 {
 	if (mCategoriesObserver && gInventory.containsObserver(mCategoriesObserver))
 	{
@@ -683,18 +683,18 @@ LLFloaterMerchantItems::~LLFloaterMerchantItems()
 	delete mCategoryAddedObserver;
 }
 
-BOOL LLFloaterMerchantItems::postBuild()
+BOOL LLFloaterMarketplaceListings::postBuild()
 {
-	mInventoryPlaceholder = getChild<LLView>("merchant_items_inventory_placeholder_panel");
-	mInventoryText = mInventoryPlaceholder->getChild<LLTextBox>("merchant_items_inventory_placeholder_text");
-	mInventoryTitle = mInventoryPlaceholder->getChild<LLTextBox>("merchant_items_inventory_placeholder_title");
+	mInventoryPlaceholder = getChild<LLView>("marketplace_listings_inventory_placeholder_panel");
+	mInventoryText = mInventoryPlaceholder->getChild<LLTextBox>("marketplace_listings_inventory_placeholder_text");
+	mInventoryTitle = mInventoryPlaceholder->getChild<LLTextBox>("marketplace_listings_inventory_placeholder_title");
 
-	mTopLevelDropZone = getChild<LLPanel>("merchant_items_generic_drag_target");
+	mTopLevelDropZone = getChild<LLPanel>("marketplace_listings_generic_drag_target");
     
-	LLFocusableElement::setFocusReceivedCallback(boost::bind(&LLFloaterMerchantItems::onFocusReceived, this));
+	LLFocusableElement::setFocusReceivedCallback(boost::bind(&LLFloaterMarketplaceListings::onFocusReceived, this));
     
-	// Observe category creation to catch merchant items creation (moot if already existing)
-	mCategoryAddedObserver = new LLMerchantItemsAddedObserver(this);
+	// Observe category creation to catch marketplace listings creation (moot if already existing)
+	mCategoryAddedObserver = new LLMarketplaceListingsAddedObserver(this);
 	gInventory.addObserver(mCategoryAddedObserver);
 	
     // Merov : Debug : fetch aggressively so we can create test data right onOpen()
@@ -704,7 +704,7 @@ BOOL LLFloaterMerchantItems::postBuild()
 	return TRUE;
 }
 
-void LLFloaterMerchantItems::clean()
+void LLFloaterMarketplaceListings::clean()
 {
     // Note: we cannot delete the mOutboxInventoryPanel as that point
     // as this is called through callback observers of the panel itself.
@@ -714,11 +714,11 @@ void LLFloaterMerchantItems::clean()
     mRootFolderId.setNull();
 }
 
-void LLFloaterMerchantItems::onClose(bool app_quitting)
+void LLFloaterMarketplaceListings::onClose(bool app_quitting)
 {
 }
 
-void LLFloaterMerchantItems::onOpen(const LLSD& key)
+void LLFloaterMarketplaceListings::onOpen(const LLSD& key)
 {
 	//
 	// Initialize the Market Place or go update the outbox
@@ -763,12 +763,12 @@ void LLFloaterMerchantItems::onOpen(const LLSD& key)
 	fetchContents();
 }
 
-void LLFloaterMerchantItems::onFocusReceived()
+void LLFloaterMarketplaceListings::onFocusReceived()
 {
 	fetchContents();
 }
 
-void LLFloaterMerchantItems::fetchContents()
+void LLFloaterMarketplaceListings::fetchContents()
 {
 	if (mRootFolderId.notNull())
 	{
@@ -776,7 +776,7 @@ void LLFloaterMerchantItems::fetchContents()
 	}
 }
 
-void LLFloaterMerchantItems::setup()
+void LLFloaterMarketplaceListings::setup()
 {
 	if (LLMarketplaceInventoryImporter::getInstance()->getMarketPlaceStatus() != MarketplaceStatusCodes::MARKET_PLACE_MERCHANT)
 	{
@@ -784,24 +784,24 @@ void LLFloaterMerchantItems::setup()
 		return;
 	}
     
-	// We are a merchant. Get the Merchant items folder, create it if needs be.
-	LLUUID outbox_id = gInventory.findCategoryUUIDForType(LLFolderType::FT_MERCHANT_ITEMS, true);
+	// We are a merchant. Get the Marketplace listings folder, create it if needs be.
+	LLUUID outbox_id = gInventory.findCategoryUUIDForType(LLFolderType::FT_MARKETPLACE_LISTINGS, true);
 	if (outbox_id.isNull())
 	{
 		// We should never get there unless the inventory fails badly
-		llinfos << "Merov : Inventory problem: failure to create the merchant items folder for a merchant!" << llendl;
-		llerrs << "Inventory problem: failure to create the merchant items folder for a merchant!" << llendl;
+		llinfos << "Merov : Inventory problem: failure to create the marketplace listings folder for a merchant!" << llendl;
+		llerrs << "Inventory problem: failure to create the marketplace listings folder for a merchant!" << llendl;
 		return;
 	}
     
-    // Consolidate Merchant items
+    // Consolidate Marketplace listings
     // We shouldn't have to do that but with a client/server system relying on a "well known folder" convention, things get messy and conventions get broken down eventually
-    gInventory.consolidateForType(outbox_id, LLFolderType::FT_MERCHANT_ITEMS);
+    gInventory.consolidateForType(outbox_id, LLFolderType::FT_MARKETPLACE_LISTINGS);
     
     if (outbox_id == mRootFolderId)
     {
-        llinfos << "Merov : Inventory warning: Merchant items folder already set" << llendl;
-        llwarns << "Inventory warning: Merchant items folder already set" << llendl;
+        llinfos << "Merov : Inventory warning: Marketplace listings folder already set" << llendl;
+        llwarns << "Inventory warning: Marketplace listings folder already set" << llendl;
         return;
     }
     mRootFolderId = outbox_id;
@@ -815,7 +815,7 @@ void LLFloaterMerchantItems::setup()
 	}
 	llassert(!mCategoryAddedObserver);
 	
 	// Create observer for merchant items modifications : clear the old one and create a new one
 	if (mCategoriesObserver && gInventory.containsObserver(mCategoriesObserver))
 	{
 		gInventory.removeObserver(mCategoriesObserver);
@@ -823,16 +823,16 @@ void LLFloaterMerchantItems::setup()
 	}
     mCategoriesObserver = new LLInventoryCategoriesObserver();
     gInventory.addObserver(mCategoriesObserver);
-    mCategoriesObserver->addCategory(mRootFolderId, boost::bind(&LLFloaterMerchantItems::onChanged, this));
+    mCategoriesObserver->addCategory(mRootFolderId, boost::bind(&LLFloaterMarketplaceListings::onChanged, this));
 	llassert(mCategoriesObserver);
 	
 	// Set up the merchant items inventory view
 	LLInventoryPanel* inventory_panel = mInventoryPanel.get();
     if (inventory_panel)
     {
         delete inventory_panel;
     }
-    inventory_panel = LLUICtrlFactory::createFromFile<LLInventoryPanel>("panel_merchant_items_inventory.xml", mInventoryPlaceholder->getParent(), LLInventoryPanel::child_registry_t::instance());
+    inventory_panel = LLUICtrlFactory::createFromFile<LLInventoryPanel>("panel_marketplace_listings_inventory.xml", mInventoryPlaceholder->getParent(), LLInventoryPanel::child_registry_t::instance());
     mInventoryPanel = inventory_panel->getInventoryPanelHandle();
 	llassert(mInventoryPanel.get() != NULL);
 	
@@ -844,11 +844,11 @@ void LLFloaterMerchantItems::setup()
 	inventory_panel->getFolderViewModel()->setSorter(LLInventoryFilter::SO_FOLDERS_BY_NAME);
 	inventory_panel->getFilter().markDefault();
     
 	// Get the content of the merchant items folder
 	fetchContents();
 }
 
-void LLFloaterMerchantItems::initializeMarketPlace()
+void LLFloaterMarketplaceListings::initializeMarketPlace()
 {
 	//
 	// Initialize the marketplace import API
@@ -857,14 +857,14 @@ void LLFloaterMerchantItems::initializeMarketPlace()
 	
     if (!importer.isInitialized())
     {
-        importer.setInitializationErrorCallback(boost::bind(&LLFloaterMerchantItems::initializationReportError, this, _1, _2));
-        importer.setStatusChangedCallback(boost::bind(&LLFloaterMerchantItems::importStatusChanged, this, _1));
-        importer.setStatusReportCallback(boost::bind(&LLFloaterMerchantItems::importReportResults, this, _1, _2));
+        importer.setInitializationErrorCallback(boost::bind(&LLFloaterMarketplaceListings::initializationReportError, this, _1, _2));
+        importer.setStatusChangedCallback(boost::bind(&LLFloaterMarketplaceListings::importStatusChanged, this, _1));
+        importer.setStatusReportCallback(boost::bind(&LLFloaterMarketplaceListings::importReportResults, this, _1, _2));
         importer.initialize();
     }
 }
 
-S32 LLFloaterMerchantItems::getFolderCount()
+S32 LLFloaterMarketplaceListings::getFolderCount()
 {
 	if (mInventoryPanel.get() && mRootFolderId.notNull())
 	{
@@ -880,7 +880,7 @@ S32 LLFloaterMerchantItems::getFolderCount()
     }
 }
 
-void LLFloaterMerchantItems::updateView()
+void LLFloaterMarketplaceListings::updateView()
 {
 	LLInventoryPanel* panel = mInventoryPanel.get();
     
@@ -915,10 +915,10 @@ void LLFloaterMerchantItems::updateView()
             {
                 setup();
             }
-            // "Merchant items is empty!" message strings
-            text = LLTrans::getString("InventoryMerchantItemsNoItems", subs);
-            title = LLTrans::getString("InventoryMerchantItemsNoItemsTitle");
-            tooltip = LLTrans::getString("InventoryMerchantItemsNoItemsTooltip");
+            // "Marketplace listings is empty!" message strings
+            text = LLTrans::getString("InventoryMarketplaceListingsNoItems", subs);
+            title = LLTrans::getString("InventoryMarketplaceListingsNoItemsTitle");
+            tooltip = LLTrans::getString("InventoryMarketplaceListingsNoItemsTooltip");
         }
         else if (mkt_status <= MarketplaceStatusCodes::MARKET_PLACE_INITIALIZING)
         {
@@ -948,14 +948,14 @@ void LLFloaterMerchantItems::updateView()
     }
 }
 
-bool LLFloaterMerchantItems::isAccepted(EAcceptance accept)
+bool LLFloaterMarketplaceListings::isAccepted(EAcceptance accept)
 {
     // *TODO : Need a bit more test on what we accept: depends of what and where...
 	return (accept >= ACCEPT_YES_COPY_SINGLE);
 }
 
 
-BOOL LLFloaterMerchantItems::handleDragAndDrop(S32 x, S32 y, MASK mask, BOOL drop,
+BOOL LLFloaterMarketplaceListings::handleDragAndDrop(S32 x, S32 y, MASK mask, BOOL drop,
 										EDragAndDropType cargo_type,
 										void* cargo_data,
 										EAcceptance* accept,
@@ -1006,21 +1006,21 @@ BOOL LLFloaterMerchantItems::handleDragAndDrop(S32 x, S32 y, MASK mask, BOOL dro
 	return handled;
 }
 
-BOOL LLFloaterMerchantItems::handleHover(S32 x, S32 y, MASK mask)
+BOOL LLFloaterMarketplaceListings::handleHover(S32 x, S32 y, MASK mask)
 {
 	mTopLevelDropZone->setBackgroundVisible(FALSE);
     
 	return LLFloater::handleHover(x, y, mask);
 }
 
-void LLFloaterMerchantItems::onMouseLeave(S32 x, S32 y, MASK mask)
+void LLFloaterMarketplaceListings::onMouseLeave(S32 x, S32 y, MASK mask)
 {
 	mTopLevelDropZone->setBackgroundVisible(FALSE);
     
 	LLFloater::onMouseLeave(x, y, mask);
 }
 
-void LLFloaterMerchantItems::onChanged()
+void LLFloaterMarketplaceListings::onChanged()
 {
     LLViewerInventoryCategory* category = gInventory.getCategory(mRootFolderId);
 	if (mRootFolderId.notNull() && category)
@@ -1034,12 +1034,12 @@ void LLFloaterMerchantItems::onChanged()
     }
 }
 
-void LLFloaterMerchantItems::initializationReportError(U32 status, const LLSD& content)
+void LLFloaterMarketplaceListings::initializationReportError(U32 status, const LLSD& content)
 {
 	updateView();
 }
 
-void LLFloaterMerchantItems::importStatusChanged(bool inProgress)
+void LLFloaterMarketplaceListings::importStatusChanged(bool inProgress)
 {
 	if (mRootFolderId.isNull() && (LLMarketplaceInventoryImporter::getInstance()->getMarketPlaceStatus() == MarketplaceStatusCodes::MARKET_PLACE_MERCHANT))
 	{
@@ -1071,7 +1071,7 @@ void LLFloaterMerchantItems::importStatusChanged(bool inProgress)
 	updateView();
 }
 
-void LLFloaterMerchantItems::importReportResults(U32 status, const LLSD& content)
+void LLFloaterMarketplaceListings::importReportResults(U32 status, const LLSD& content)
 {	
 	updateView();
 }
@@ -1,8 +1,8 @@
 /** 
  * @file llfloateroutbox.cpp
- * @brief Implementation of the merchant outbox window and of the merchant items window
+ * @brief Implementation of the merchant outbox window and of the marketplace listings window
  *
@@ -1,8 +1,8 @@
  *
- * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermerchantitems
+ * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermarketplacelistings
  *
  * $LicenseInfo:firstyear=2001&license=viewerlgpl$
@@ -107,15 +107,15 @@ class LLOutboxAddedObserver : public LLInventoryCategoryAddedObserver
 
 ///----------------------------------------------------------------------------
-/// LLMerchantItemsAddedObserver helper class
+/// LLMarketplaceListingsAddedObserver helper class
 ///----------------------------------------------------------------------------
 
@@ -815,7 +815,7 @@ void LLFloaterMerchantItems::setup()
 	llassert(!mCategoryAddedObserver);
 	
-	// Create observer for merchant items modifications : clear the old one and create a new one
+	// Create observer for marketplace listings modifications : clear the old one and create a new one
 	if (mCategoriesObserver && gInventory.containsObserver(mCategoriesObserver))
 	{
@@ -823,16 +823,16 @@ void LLFloaterMerchantItems::setup()
 	llassert(mCategoriesObserver);
 	
-	// Set up the merchant items inventory view
+	// Set up the marketplace listings inventory view
 	LLInventoryPanel* inventory_panel = mInventoryPanel.get();
     if (inventory_panel)
@@ -844,11 +844,11 @@ void LLFloaterMerchantItems::setup()
 	inventory_panel->getFilter().markDefault();
     
-	// Get the content of the merchant items folder
+	// Get the content of the marketplace listings folder
 	fetchContents();
 }
diff --git a/indra/newview/llfloateroutbox.h b/indra/newview/llfloateroutbox.h
index 1b1e1e04394..e28fb320ea1 100755
--- a/indra/newview/llfloateroutbox.h
+++ b/indra/newview/llfloateroutbox.h
@@ -1,8 +1,8 @@
 /** 
  * @file llfloateroutbox.h
  * @brief Implementation of the merchant outbox window and of the merchant items window
  *
  * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermerchantitems
  *
  * $LicenseInfo:firstyear=2001&license=viewerlgpl$
  * Second Life Viewer Source Code
@@ -115,14 +115,14 @@ class LLFloaterOutbox : public LLFloater
 };
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-// Class LLFloaterMerchantItems
+// Class LLFloaterMarketplaceListings
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
-class LLFloaterMerchantItems : public LLFloater
+class LLFloaterMarketplaceListings : public LLFloater
 {
 public:
-	LLFloaterMerchantItems(const LLSD& key);
-	~LLFloaterMerchantItems();
+	LLFloaterMarketplaceListings(const LLSD& key);
+	~LLFloaterMarketplaceListings();
 	
 	void initializeMarketPlace();
     
@@ -1,8 +1,8 @@
 /** 
  * @file llfloateroutbox.h
- * @brief Implementation of the merchant outbox window and of the merchant items window
+ * @brief Implementation of the merchant outbox window and of the marketplace listings window
  *
@@ -1,8 +1,8 @@
  *
- * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermerchantitems
+ * *TODO : Eventually, take out all the merchant outbox stuff and rename that file to llfloatermarketplacelistings
  *
  * $LicenseInfo:firstyear=2001&license=viewerlgpl$
diff --git a/indra/newview/llinventorybridge.h b/indra/newview/llinventorybridge.h
index 199a46d2756..d9533b537c8 100755
--- a/indra/newview/llinventorybridge.h
+++ b/indra/newview/llinventorybridge.h
@@ -160,7 +160,7 @@ class LLInvFVBridge : public LLFolderViewModelItemInventory
 	BOOL isInboxFolder() const;     // true if COF or descendant of   marketplace inbox
 	BOOL isOutboxFolder() const;    // true if COF or descendant of   marketplace outbox
 	BOOL isOutboxFolderDirectParent() const;
-	BOOL isMerchantItemsFolder() const;     // true if descendant of Merchant items folder
+	BOOL isMarketplaceListingsFolder() const;     // true if descendant of Marketplace listings folder
 	const LLUUID getOutboxFolder() const;
 
 	virtual BOOL isItemPermissive() const;
-- 
GitLab